@@ -230,7 +230,8 @@ def create_parser():
         help=textwrap.dedent("""\
         Audio sample rate to use for output files in Hz.
 
-        Will use input sample rate by default.
+        Will use input sample rate by default, except for EBU normalization, 
+        which will change the input sample rate to 192 kHz.
         """)
     )
     group_acodec.add_argument(
@@ -396,9 +397,11 @@ def main():
 
     for index, input_file in enumerate(cli_args.input):
         if cli_args.output is not None and index < len(cli_args.output):
+            if cli_args.output_folder and cli_args.output_folder != 'normalized':
+                logger.warning("Output folder {} is ignored for input file {}".format(cli_args.output_folder, input_file))
             output_file = cli_args.output[index]
             output_dir = os.path.dirname(output_file)
-            if not os.path.isdir(output_dir):
+            if output_dir != '' and not os.path.isdir(output_dir):
                 raise FFmpegNormalizeError("Output file path {} does not exist".format(output_dir))
         else:
             output_file = os.path.join(
