@@ -277,6 +277,12 @@ class MediaFile():
             cmd.extend(['-b:a', str(self.ffmpeg_normalize.audio_bitrate)])
         if self.ffmpeg_normalize.sample_rate:
             cmd.extend(['-ar', str(self.ffmpeg_normalize.sample_rate)])
+        else:
+            if self.ffmpeg_normalize.normalization_type == "ebu":
+                logger.warn(
+                    "The sample rate will automatically be set to 192 kHz by the loudnorm filter. "
+                    "Specify -ar/--sample-rate to override it."
+                )
 
         # ... and subtitles
         if not self.ffmpeg_normalize.subtitle_disable:
@@ -323,7 +329,12 @@ class MediaFile():
                 for progress in cmd_runner.run_ffmpeg_command():
                     yield progress
             except Exception as e:
-                logger.error("Error while running command {}! Error: {}".format(" ".join([shlex.quote(c) for c in cmd])), e)
+                logger.error(
+                    "Error while running command {}! Error: {}".format(
+                        " ".join([shlex.quote(c) for c in cmd]),
+                        e
+                    )
+                )
             else:
                 # move file from TMP to output file
                 logger.debug(
